/**
 * Universitat Oberta de Catalunya
 * Ingeniera de Informtica
 * Proyecto fin de carrera
 * 
 * @author      Miguel Arias Fernndez 
 * @version     1.0    
 * 
 */
package es.uoc.maf.ejemplo.actions;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import es.uoc.maf.core.enums.ActionResults;
import es.uoc.maf.core.locale.I18N;
import es.uoc.maf.ejemplo.forms.DetalleMovimientoForm;
import es.uoc.maf.ejemplo.model.dao.impl.DAOUtils;
import es.uoc.maf.ejemplo.model.dao.vo.CuentaVO;
import es.uoc.maf.ejemplo.model.dao.vo.TransferenciaVO;
import es.uoc.maf.ejemplo.model.dao.vo.UsuarioVO;
import es.uoc.maf.framework.action.BaseAction;

/**
 * The Class DetalleMovimientoAction.
 * 
 * @author Miguel Arias Fernndez
 * @version 1.0
 */
public class DetalleMovimientoAction extends BaseAction {
	
	/** The Constant LOG. */
	private static final Logger LOG = LoggerFactory.getLogger(DetalleMovimientoAction.class);
	
	/** The detalle. */
	private String detalle;
	
	/**
	 * Gets the detalle.
	 * 
	 * @return the detalle
	 */
	public String getDetalle() {
		return detalle;
	}

	/* (non-Javadoc)
	 * @see es.uoc.maf.framework.action.BaseAction#execute()
	 */
	@Override
	public String execute() {
		DetalleMovimientoForm form = (DetalleMovimientoForm)getForm();
		TransferenciaVO transferencia = DAOUtils.getTransferenciaDAO().findById(form.getIdMovimiento());
		StringBuilder sb = new StringBuilder();
		if (transferencia == null) {
			sb.append( I18N.getString(getClass(), "detalle.sindetalle"));
		}
		else {
			CuentaVO origen = transferencia.getOrigen();
			CuentaVO destino = transferencia.getDestino();
			UsuarioVO ordenante = origen.getTitular();
			UsuarioVO beneficiario = destino.getTitular();
			String cabecera = I18N.getString(getClass(), "detalle.movimiento");
			LOG.debug("cabecera: {}",cabecera);
			sb.append( cabecera+"\r\n");
			sb.append( I18N.getString(getClass(), "detalle.ordenante")	+" "+ordenante.getApellidos()+", "+ordenante.getNombre()+"\r\n");
			sb.append( I18N.getString(getClass(), "detalle.cuentaOrigen")+" "+origen.getDescripcion()+"\r\n");
			sb.append( I18N.getString(getClass(), "detalle.beneficiario")+" "+beneficiario.getApellidos()+", "+beneficiario.getNombre()+"\r\n");
			sb.append( I18N.getString(getClass(), "detalle.cuentaDestino")+" "+destino.getDescripcion()+"\r\n");
			sb.append( I18N.getString(getClass(), "detalle.fecha")+" "+transferencia.getFecha()+"\r\n");
			sb.append( I18N.getString(getClass(), "detalle.cantidad")+" "+transferencia.getCantidad()+"\r\n");
		}
		detalle = sb.toString();
		return ActionResults.OK.name();
	}
	
}
