/**
 * Universitat Oberta de Catalunya
 * Ingeniera de Informtica
 * Proyecto fin de carrera
 * 
 * @author      Miguel Arias Fernndez 
 * @version     1.0    
 * 
 */
package es.uoc.maf.ejemplo.actions;

import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import es.uoc.maf.core.enums.ActionResults;
import es.uoc.maf.core.locale.I18N;
import es.uoc.maf.ejemplo.model.dao.impl.DAOUtils;
import es.uoc.maf.ejemplo.model.dao.vo.CuentaVO;
import es.uoc.maf.ejemplo.model.dao.vo.UsuarioVO;
import es.uoc.maf.framework.action.BaseAction;

/**
 * The Class ListarCuentasAction.
 * 
 * @author Miguel Arias Fernndez
 * @version 1.0
 */
public class ListarCuentasAction extends BaseAction {
	
	/** The Constant LOG. */
	private static final Logger LOG = LoggerFactory.getLogger(ListarCuentasAction.class);
	
	/** The cuentas. */
	private List<CuentaVO> cuentas;
	
	/**
	 * Gets the cuentas.
	 * 
	 * @return the cuentas
	 */
	public List<CuentaVO> getCuentas() {
		return cuentas;
	}

	/* (non-Javadoc)
	 * @see es.uoc.maf.framework.action.BaseAction#execute()
	 */
	@Override
	public String execute() {
		LOG.debug("ListarCuentas.execute()...");
		// Recuperamos el usuario almacenado en la sesion
		UsuarioVO usuario = (UsuarioVO) getActionContext().getSession().getAttribute("usuario");
		if (usuario == null) {
			addActionError(I18N.getString("messages/ejemplo", "usuario.nologado"));
			return "noUsuario";
		}
		cuentas = DAOUtils.getCuentaDAO().findCuentasUsuario(usuario.getId());
		LOG.debug("Encontradas {} cuentas.",cuentas == null ? 0 : cuentas.size());
		return ActionResults.OK.name();
	}

	
}
