/**
 * Universitat Oberta de Catalunya
 * Ingeniera de Informtica
 * Proyecto fin de carrera
 * 
 * @author      Miguel Arias Fernndez 
 * @version     1.0    
 * 
 */
package es.uoc.maf.ejemplo.actions;

import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import es.uoc.maf.core.enums.ActionResults;
import es.uoc.maf.core.locale.I18N;
import es.uoc.maf.ejemplo.forms.LoginForm;
import es.uoc.maf.ejemplo.model.dao.impl.DAOUtils;
import es.uoc.maf.ejemplo.model.dao.vo.UsuarioVO;
import es.uoc.maf.framework.action.BaseAction;

/**
 * The Class LoginAction.
 * 
 * @author Miguel Arias Fernndez
 * @version 1.0
 */
public class LoginAction extends BaseAction {
	
	/** The Constant LOG. */
	private static final Logger LOG = LoggerFactory.getLogger(LoginAction.class);
	
	/* (non-Javadoc)
	 * @see es.uoc.maf.framework.action.BaseAction#execute()
	 */
	public String execute() {
		LOG.debug("LoginAction.execute()...");
		LoginForm form = (LoginForm)getForm();
		if (form.hasErrors()) {
			return ActionResults.ERROR.name();
		}
		UsuarioVO usuario = DAOUtils.getUsuarioDAO().findByCodigo(form.getCodigo());
		if (usuario == null) {
			LOG.debug("Usuario no encontrado '{}'",form.getCodigo());
			addActionError(I18N.getString(LoginAction.class, "usuario.noencontrado"));
			return ActionResults.ERROR.name();
		}
		if (!StringUtils.equals(usuario.getClave(), form.getClave())) {
			LOG.debug("Clave incorrecta.");
			addActionError(I18N.getString(LoginAction.class, "usuario.claveincorrecta"));
			return ActionResults.ERROR.name();
		}
		// Guardamos el usuario en la session para futuros usos
		getActionContext().getSession().setAttribute("usuario", usuario);
		return ActionResults.OK.name();
	}
}
