/**
 * Universitat Oberta de Catalunya
 * Ingeniera de Informtica
 * Proyecto fin de carrera
 * 
 * @author      Miguel Arias Fernndez 
 * @version     1.0    
 * 
 */
package es.uoc.maf.ejemplo.actions;

import java.util.List;

import org.apache.commons.collections.CollectionUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import es.uoc.maf.core.enums.ActionResults;
import es.uoc.maf.core.locale.I18N;
import es.uoc.maf.ejemplo.forms.MovimientosForm;
import es.uoc.maf.ejemplo.model.dao.impl.DAOUtils;
import es.uoc.maf.ejemplo.model.dao.vo.CuentaVO;
import es.uoc.maf.ejemplo.model.dao.vo.TransferenciaVO;
import es.uoc.maf.framework.action.BaseAction;

/**
 * The Class MovimientosAction.
 * 
 * @author Miguel Arias Fernndez
 * @version 1.0
 */
public class MovimientosAction extends BaseAction {
	
	/** The Constant LOG. */
	private static final Logger LOG = LoggerFactory.getLogger(MovimientosAction.class);
	
	/** The cuenta. */
	private CuentaVO cuenta;
	
	/** The movimientos. */
	private List<TransferenciaVO> movimientos;
	
	/**
	 * Gets the cuenta.
	 * 
	 * @return the cuenta
	 */
	public CuentaVO getCuenta() {
		return cuenta;
	}

	/**
	 * Gets the movimientos.
	 * 
	 * @return the movimientos
	 */
	public List<TransferenciaVO> getMovimientos() {
		return movimientos;
	}

	/* (non-Javadoc)
	 * @see es.uoc.maf.framework.action.BaseAction#execute()
	 */
	@Override
	public String execute() {
		LOG.debug("MovimientosAction.execute()...");
		MovimientosForm form = (MovimientosForm) getForm();
		if (form.hasErrors()) {
			LOG.error("Error en formulario: {}", form.getFormErrors());
			return ActionResults.ERROR.name();
		}
		
		cuenta = DAOUtils.getCuentaDAO().findById(form.getIdCuenta());
		LOG.debug("Cuenta encontrada: {}",cuenta == null ? "NULA" : cuenta.getDescripcion());
		if (cuenta == null) {
			super.addActionError(I18N.getString(getClass(), "cuenta.noencontrada"));
			return ActionResults.ERROR.name();
		}
		
		movimientos = DAOUtils.getTransferenciaDAO().findByIdCuenta(cuenta.getId());
		LOG.debug("Se han encontrado {} movimientos...",movimientos == null ? 0 : CollectionUtils.size(movimientos));
		return ActionResults.OK.name();
	}
	
}
