/**
 * Universitat Oberta de Catalunya
 * Ingeniera de Informtica
 * Proyecto fin de carrera
 * 
 * @author      Miguel Arias Fernndez 
 * @version     1.0    
 * 
 */
package es.uoc.maf.ejemplo.actions;

import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import es.uoc.maf.core.enums.ActionResults;
import es.uoc.maf.core.locale.I18N;
import es.uoc.maf.ejemplo.forms.TransferenciaForm;
import es.uoc.maf.ejemplo.model.dao.impl.DAOUtils;
import es.uoc.maf.ejemplo.model.dao.vo.CuentaVO;
import es.uoc.maf.ejemplo.model.dao.vo.TransferenciaVO;
import es.uoc.maf.ejemplo.model.dao.vo.UsuarioVO;
import es.uoc.maf.framework.action.BaseAction;

/**
 * The Class TransferenciaAction.
 * 
 * @author Miguel Arias Fernndez
 * @version 1.0
 */
public class TransferenciaAction extends BaseAction {
	
	/** The Constant LOG. */
	private static final Logger LOG = LoggerFactory.getLogger(TransferenciaAction.class);

	/** The cuentas usuario. */
	private List<CuentaVO> cuentasUsuario;
	
	/** The cuentas destino. */
	private List<CuentaVO> cuentasDestino;
	
	/**
	 * Gets the cuentas usuario.
	 * 
	 * @return the cuentas usuario
	 */
	public List<CuentaVO> getCuentasUsuario() {
		return cuentasUsuario;
	}

	/**
	 * Gets the cuentas destino.
	 * 
	 * @return the cuentas destino
	 */
	public List<CuentaVO> getCuentasDestino() {
		return cuentasDestino;
	}

	/* (non-Javadoc)
	 * @see es.uoc.maf.framework.action.BaseAction#execute()
	 */
	@Override
	public String execute() {
		LOG.debug("TransferenciaAction.execute()...");
		// Recuperamos el usuario en la session para futuros usos
		UsuarioVO usuario = (UsuarioVO) getActionContext().getSession().getAttribute("usuario");
		if (usuario == null) {
			addActionError(I18N.getString("messages/ejemplo", "usuario.nologado"));
			return "noUsuario";
		}
		cuentasUsuario = DAOUtils.getCuentaDAO().findCuentasUsuario(usuario.getId());
		cuentasDestino = DAOUtils.getCuentaDAO().findAll();
		
		TransferenciaForm form = (TransferenciaForm)getForm();
		if (form.hasErrors() || form.isInicio()) {
			// Si hay errores o es el inicio (falta la cuenta destino y la cantidad), vamos a la pagina de transferencia
			return ActionResults.ERROR.name();
		}
		
		CuentaVO cuentaOrigen = DAOUtils.getCuentaDAO().findById(form.getIdCuentaOrigen());
		LOG.debug("Cuenta origen encontrada: {}",cuentaOrigen == null ? "NULA" : cuentaOrigen.getDescripcion());
		if (cuentaOrigen == null) {
			super.addActionError(I18N.getString(TransferenciaAction.class, "cuentaOrigen.noencontrada"));
			return ActionResults.ERROR.name();
		}
		CuentaVO cuentaDestino = DAOUtils.getCuentaDAO().findById(form.getIdCuentaDestino());
		LOG.debug("Cuenta destino encontrada: {}",cuentaDestino == null ? "NULA" : cuentaDestino.getDescripcion());
		if (cuentaDestino == null) {
			super.addActionError(I18N.getString(TransferenciaAction.class, "cuentaDestino.noencontrada"));
			return ActionResults.ERROR.name();
		}
		if (cuentaOrigen.getSaldo() < form.getCantidad()) {
			super.addActionError(I18N.getString(TransferenciaAction.class, "saldo.insuficiente"));
			return ActionResults.ERROR.name();
		}
		LOG.debug("Creando transferencia...");
		TransferenciaVO transferencia = new TransferenciaVO();
		transferencia.setOrigen(cuentaOrigen);
		transferencia.setDestino(cuentaDestino);
		transferencia.setCantidad(form.getCantidad());
		
		transferencia = DAOUtils.getTransferenciaDAO().create(cuentaOrigen, cuentaDestino, form.getCantidad());
		LOG.debug("Transferencia creada: {}",transferencia);
		
		return ActionResults.OK.name();
	}
	
}
