/**
 * Universitat Oberta de Catalunya
 * Ingeniera de Informtica
 * Proyecto fin de carrera
 * 
 * @author      Miguel Arias Fernndez 
 * @version     1.0    
 * 
 */
package es.uoc.maf.ejemplo.errors;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import es.uoc.maf.core.Constants;
import es.uoc.maf.core.action.Action;
import es.uoc.maf.core.action.utils.ActionContext;
import es.uoc.maf.core.error.ErrorHandler;

/**
 * The Class GlobalErrorHandler.
 * 
 * @author Miguel Arias Fernndez
 * @version 1.0
 */
public class GlobalErrorHandler implements ErrorHandler {
	
	/** The Constant LOG. */
	private static final Logger LOG = LoggerFactory.getLogger(GlobalErrorHandler.class);
	
	/** The error page. */
	private String errorPage;
	
	/**
	 * Gets the error page.
	 * 
	 * @return the error page
	 */
	public String getErrorPage() {
		return errorPage;
	}

	/**
	 * Sets the error page.
	 * 
	 * @param errorPage
	 *            the new error page
	 */
	public void setErrorPage(String errorPage) {
		LOG.debug("setErrorPage: {}",errorPage);
		this.errorPage = errorPage;
	}

	/* (non-Javadoc)
	 * @see es.uoc.maf.core.error.ErrorHandler#handle(java.lang.Throwable, es.uoc.maf.core.action.Action, es.uoc.maf.core.action.utils.ActionContext)
	 */
	public void handle(Throwable error, Action action, ActionContext actionContext) {
		actionContext.getRequest().setAttribute(Constants.ACTION_CONTEXT_KEY, actionContext);
		actionContext.getRequest().setAttribute(Constants.EXCEPTION_KEY, error);
		try {
			actionContext.getRequest().getRequestDispatcher(errorPage).forward(
					actionContext.getRequest(), 
					actionContext.getResponse());
		} catch (Throwable e) {
			LOG.debug("Error procesando error handler; {}",e.getMessage(),e);
			LOG.debug("Generando pagina con error por defecto.");
			try {
				actionContext.getResponse().getWriter().write("ERROR:\n");
				error.printStackTrace(actionContext.getResponse().getWriter());
			} catch (Throwable e1) {
				LOG.debug("Error generando pgina por defecto: {}",e1.getMessage(),e1);
				throw new RuntimeException(error);
			}
		} 
	}

}
