/**
 * Universitat Oberta de Catalunya
 * Ingeniera de Informtica
 * Proyecto fin de carrera
 * 
 * @author      Miguel Arias Fernndez 
 * @version     1.0    
 * 
 */
package es.uoc.maf.ejemplo.forms;

import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import es.uoc.maf.core.action.utils.ActionContext;
import es.uoc.maf.core.form.FormError;
import es.uoc.maf.core.locale.I18N;
import es.uoc.maf.framework.form.BaseFormBean;

/**
 * The Class LoginForm.
 * 
 * @author Miguel Arias Fernndez
 * @version 1.0
 */
public class LoginForm extends BaseFormBean {
	
	/** The Constant log. */
	private static final Logger log = LoggerFactory.getLogger(LoginForm.class);
	
	/** The codigo. */
	private String codigo;
	
	/** The clave. */
	private String clave;
	
	/**
	 * Gets the codigo.
	 * 
	 * @return the codigo
	 */
	public String getCodigo() {
		return codigo;
	}

	/**
	 * Sets the codigo.
	 * 
	 * @param codigo
	 *            the new codigo
	 */
	public void setCodigo(String codigo) {
		this.codigo = codigo;
	}

	/**
	 * Gets the clave.
	 * 
	 * @return the clave
	 */
	public String getClave() {
		return clave;
	}

	/**
	 * Sets the clave.
	 * 
	 * @param clave
	 *            the new clave
	 */
	public void setClave(String clave) {
		this.clave = clave;
	}

	/* (non-Javadoc)
	 * @see es.uoc.maf.framework.form.BaseFormBean#reset()
	 */
	public void reset() {
		log.debug("Reset formulario...");
		this.codigo = "";
		this.clave = "";
	}

	/* (non-Javadoc)
	 * @see es.uoc.maf.framework.form.BaseFormBean#validate()
	 */
	public void validate() {
		log.debug("Validate formulario...");
		if (StringUtils.isBlank(codigo)) {
			super.addError(new FormError(codigo, I18N.getString(LoginForm.class, "codigo.invalido", ActionContext.getLocale())));
		}
		if (StringUtils.isBlank(clave)) {
			super.addError(new FormError(clave, I18N.getString(LoginForm.class, "clave.invalido", ActionContext.getLocale())));
		}
	}



}
