/**
 * Universitat Oberta de Catalunya
 * Ingeniera de Informtica
 * Proyecto fin de carrera
 * 
 * @author      Miguel Arias Fernndez 
 * @version     1.0    
 * 
 */
package es.uoc.maf.ejemplo.forms;

import es.uoc.maf.core.action.utils.ActionContext;
import es.uoc.maf.core.form.FormError;
import es.uoc.maf.core.locale.I18N;
import es.uoc.maf.framework.form.BaseFormBean;

/**
 * The Class TransferenciaForm.
 * 
 * @author Miguel Arias Fernndez
 * @version 1.0
 */
public class TransferenciaForm extends BaseFormBean {

	/** The inicio. */
	private boolean inicio = false;
	
	/** The id cuenta origen. */
	private int idCuentaOrigen = -1;
	
	/** The id cuenta destino. */
	private int idCuentaDestino = -1;
	
	/** The cantidad. */
	private double cantidad = 0.0;

	/**
	 * Checks if is inicio.
	 * 
	 * @return true, if is inicio
	 */
	public boolean isInicio() {
		return inicio;
	}

	/**
	 * Sets the inicio.
	 * 
	 * @param inicio
	 *            the new inicio
	 */
	public void setInicio(boolean inicio) {
		this.inicio = inicio;
	}

	/**
	 * Gets the id cuenta origen.
	 * 
	 * @return the id cuenta origen
	 */
	public int getIdCuentaOrigen() {
		return idCuentaOrigen;
	}

	/**
	 * Sets the id cuenta origen.
	 * 
	 * @param idCuenta
	 *            the new id cuenta origen
	 */
	public void setIdCuentaOrigen(int idCuenta) {
		this.idCuentaOrigen = idCuenta;
	}
	
	/**
	 * Gets the id cuenta destino.
	 * 
	 * @return the id cuenta destino
	 */
	public int getIdCuentaDestino() {
		return idCuentaDestino;
	}
	
	/**
	 * Sets the id cuenta destino.
	 * 
	 * @param idCuentaDestino
	 *            the new id cuenta destino
	 */
	public void setIdCuentaDestino(int idCuentaDestino) {
		this.idCuentaDestino = idCuentaDestino;
	}
	
	/**
	 * Gets the cantidad.
	 * 
	 * @return the cantidad
	 */
	public double getCantidad() {
		return cantidad;
	}
	
	/**
	 * Sets the cantidad.
	 * 
	 * @param cantidad
	 *            the new cantidad
	 */
	public void setCantidad(double cantidad) {
		this.cantidad = cantidad;
	}

	/* (non-Javadoc)
	 * @see es.uoc.maf.framework.form.BaseFormBean#reset()
	 */
	@Override
	public void reset() {
		this.idCuentaOrigen = -1;
		this.idCuentaDestino = -1;
		this.cantidad = 0.0;
	}

	/* (non-Javadoc)
	 * @see es.uoc.maf.framework.form.BaseFormBean#validate()
	 */
	@Override
	public void validate() {
		if (!inicio) {
			// Si no estamos entrando en la accin, validamos todos los campos
			if (this.idCuentaOrigen == -1) {
				super.addError(new FormError("idCuentaOrigen", I18N.getString(getClass(), "idCuentaOrigen.invalido", ActionContext.getLocale())));
			}
			if (this.idCuentaDestino == -1) {
				super.addError(new FormError("idCuentaDestino", I18N.getString(getClass(), "idCuentaDestino.invalido", ActionContext.getLocale())));
			}
			if (idCuentaOrigen == idCuentaDestino && idCuentaOrigen != -1) {
				super.addError(new FormError("", I18N.getString(getClass(), "cuentas.iguales", ActionContext.getLocale())));
			}
			if (this.cantidad <= 0) {
				super.addError(new FormError("cantidad", I18N.getString(getClass(), "cantidad.invalido", ActionContext.getLocale())));
			}
		}
	}	

}
