/**
 * Universitat Oberta de Catalunya
 * Ingeniera de Informtica
 * Proyecto fin de carrera
 * 
 * @author      Miguel Arias Fernndez 
 * @version     1.0    
 * 
 */
package es.uoc.maf.ejemplo.model.dao.impl;

import java.io.Serializable;
import java.lang.reflect.ParameterizedType;
import java.lang.reflect.Type;
import java.util.List;

import org.hibernate.Criteria;
import org.hibernate.Session;
import org.hibernate.criterion.Criterion;

import es.uoc.maf.ejemplo.model.dao.GenericDAO;
import es.uoc.maf.ejemplo.model.dao.utils.HibernateUtils;
import es.uoc.maf.ejemplo.model.dao.vo.BaseVO;

/**
 * The Class GenericDAOImpl.
 * 
 * @param <PK>
 *            the generic type
 * @param <Entidad>
 *            the generic type
 * @author Miguel Arias Fernndez
 * @version 1.0
 */
abstract class GenericDAOImpl<PK extends Serializable, Entidad extends BaseVO> implements GenericDAO<PK, Entidad> {

	/** The clase pk. */
	private Class<PK> clasePK;
	
	/** The clase entidad. */
	private Class<Entidad> claseEntidad;
	
	/**
	 * Instantiates a new generic dao impl.
	 */
	@SuppressWarnings("unchecked")
	public GenericDAOImpl() {
		Type[] actualTypeArguments = ((ParameterizedType) getClass().getGenericSuperclass()).getActualTypeArguments();
		this.clasePK = (Class<PK>) actualTypeArguments[0];
		this.claseEntidad = (Class<Entidad>) actualTypeArguments[1];
	}
	
	/**
	 * Gets the session.
	 * 
	 * @return the session
	 */
	public Session getSession() {
		return HibernateUtils.getSessionFactory().getCurrentSession();
	}

	/* (non-Javadoc)
	 * @see es.uoc.maf.ejemplo.model.dao.GenericDAO#findById(java.io.Serializable)
	 */
	@SuppressWarnings("unchecked")
	public Entidad findById(PK id) {
		return (Entidad) getSession().get(claseEntidad, id);
	}

	/* (non-Javadoc)
	 * @see es.uoc.maf.ejemplo.model.dao.GenericDAO#findAll()
	 */
	@SuppressWarnings("unchecked")
	public List<Entidad> findAll() {
		return getSession().createCriteria(claseEntidad).list();
	}

	/* (non-Javadoc)
	 * @see es.uoc.maf.ejemplo.model.dao.GenericDAO#save(java.lang.Object)
	 */
	public Entidad save(Entidad entidad) {
		if (entidad.isNew()) {
			getSession().save(entidad);
		}
		else {
			getSession().update(entidad);
		}
		return entidad;
	}

	/* (non-Javadoc)
	 * @see es.uoc.maf.ejemplo.model.dao.GenericDAO#delete(java.lang.Object)
	 */
	public void delete(Entidad entidad) {
		getSession().delete(entidad);
	}

    /**
	 * Find by criteria.
	 * 
	 * @param criterion
	 *            the criterion
	 * @return the list
	 */
    @SuppressWarnings("unchecked")
    public List<Entidad> findByCriteria(Criterion... criterion) {
        Criteria crit = getSession().createCriteria(this.claseEntidad);
        for (Criterion c : criterion) {
            crit.add(c);
        }
        return crit.list();
   }
}
