/**
 * Universitat Oberta de Catalunya
 * Ingeniera de Informtica
 * Proyecto fin de carrera
 * 
 * @author      Miguel Arias Fernndez 
 * @version     1.0    
 * 
 */
package es.uoc.maf.ejemplo.model.dao.impl;

import java.util.Date;
import java.util.List;

import org.hibernate.criterion.Restrictions;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import es.uoc.maf.ejemplo.model.dao.CuentaDAO;
import es.uoc.maf.ejemplo.model.dao.TransferenciaDAO;
import es.uoc.maf.ejemplo.model.dao.vo.CuentaVO;
import es.uoc.maf.ejemplo.model.dao.vo.TransferenciaVO;

/**
 * The Class TransferenciaDAOImpl.
 * 
 * @author Miguel Arias Fernndez
 * @version 1.0
 */
class TransferenciaDAOImpl extends GenericDAOImpl<Integer, TransferenciaVO> implements TransferenciaDAO {
	
	/** The Constant LOG. */
	private static final Logger LOG = LoggerFactory.getLogger(TransferenciaDAOImpl.class);
	
	/* (non-Javadoc)
	 * @see es.uoc.maf.ejemplo.model.dao.TransferenciaDAO#findByIdCuenta(int)
	 */
	public List<TransferenciaVO> findByIdCuenta(int idCuenta) {
		LOG.debug("Buscando transferencias de cuenta {}",idCuenta);
		return super.findByCriteria(
				Restrictions.or(
						Restrictions.eq("origen.id", idCuenta),
						Restrictions.eq("destino.id", idCuenta)
				));
	}

	/* (non-Javadoc)
	 * @see es.uoc.maf.ejemplo.model.dao.impl.GenericDAOImpl#save(es.uoc.maf.ejemplo.model.dao.vo.BaseVO)
	 */
	@Override
	public TransferenciaVO save(TransferenciaVO entidad) {
		// No permitimos guardar transferencias directamente
		throw new UnsupportedOperationException();
	}

	/* (non-Javadoc)
	 * @see es.uoc.maf.ejemplo.model.dao.impl.GenericDAOImpl#delete(es.uoc.maf.ejemplo.model.dao.vo.BaseVO)
	 */
	@Override
	public void delete(TransferenciaVO entidad) {
		// No permitimos borrar transferencias directamente
		throw new UnsupportedOperationException();
	}

	/* (non-Javadoc)
	 * @see es.uoc.maf.ejemplo.model.dao.TransferenciaDAO#create(es.uoc.maf.ejemplo.model.dao.vo.CuentaVO, es.uoc.maf.ejemplo.model.dao.vo.CuentaVO, double)
	 */
	public TransferenciaVO create(CuentaVO origen, CuentaVO destino, double cantidad) {
		CuentaDAO cuentaDao = DAOUtils.getCuentaDAO();
		origen.setSaldo(origen.getSaldo() - cantidad);
		cuentaDao.save(origen);
		destino.setSaldo(destino.getSaldo() + cantidad);
		cuentaDao.save(destino);
		TransferenciaVO transferencia = new TransferenciaVO();
		transferencia.setOrigen(origen);
		transferencia.setDestino(destino);
		transferencia.setCantidad(cantidad);
		transferencia.setFecha(new Date());
		transferencia.setSaldoRestanteOrigen(origen.getSaldo());
		transferencia.setSaldoRestanteDestino(destino.getSaldo());
		return super.save(transferencia);
		
	}

}
