/**
 * Universitat Oberta de Catalunya
 * Ingeniera de Informtica
 * Proyecto fin de carrera
 * 
 * @author      Miguel Arias Fernndez 
 * @version     1.0    
 * 
 */
package es.uoc.maf.ejemplo.web.filter;

import java.io.IOException;
import java.sql.DriverManager;

import javax.servlet.Filter;
import javax.servlet.FilterChain;
import javax.servlet.FilterConfig;
import javax.servlet.ServletException;
import javax.servlet.ServletRequest;
import javax.servlet.ServletResponse;

import org.h2.tools.Server;
import org.hibernate.Transaction;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import es.uoc.maf.ejemplo.model.dao.utils.HibernateUtils;

/**
 * Implementacin de OpenSessionInView.
 * 
 * @author Miguel Arias Fernndez
 * @version 1.0
 */
public class HibernateSessionFilter implements Filter {

	/** The Constant LOG. */
	private static final Logger LOG = LoggerFactory.getLogger(HibernateSessionFilter.class);

	/** The webserver. */
	private Server webserver;
	
	/**
	 * Inits the.
	 * 
	 * @param fConfig
	 *            the f config
	 * @throws ServletException
	 *             the servlet exception
	 * @see Filter#init(FilterConfig)
	 */
	public void init(FilterConfig fConfig) throws ServletException {
		LOG.debug("Iniciando servidor de base de datos...");
		try {
			webserver = Server.createWebServer().start();
			Class.forName("org.h2.Driver");
			DriverManager.getConnection("jdbc:h2:mem:","sa","");
		} catch (Throwable e) {
			LOG.debug("Error iniciando servidor de base de datos.",e);
			throw new ServletException(e.getMessage(), e);
		}
		LOG.debug("Servidor de base de datos iniciado.");
	}
	
	/**
	 * Destroy.
	 * 
	 * @see Filter#destroy()
	 */
	public void destroy() {
		if (webserver != null) {
			LOG.debug("Deteniendo servidor de base de datos...");
			webserver.shutdown();
		}
	}

	/**
	 * Do filter.
	 * 
	 * @param request
	 *            the request
	 * @param response
	 *            the response
	 * @param chain
	 *            the chain
	 * @throws IOException
	 *             Signals that an I/O exception has occurred.
	 * @throws ServletException
	 *             the servlet exception
	 * @see Filter#doFilter(ServletRequest, ServletResponse, FilterChain)
	 */
	public void doFilter(ServletRequest request, ServletResponse response, FilterChain chain) throws IOException, ServletException {
		Transaction transaction = null;
		try {
			LOG.debug("Iniciando transaccin...");
			transaction = HibernateUtils.getSessionFactory().getCurrentSession().beginTransaction();

			chain.doFilter(request, response);
            
			LOG.debug("Confirmando transaccin...");
            transaction.commit();
		}
		catch (Throwable t) {
			if (transaction != null && transaction.isActive()) {
				LOG.debug("Rollback de trasaccin...");
				transaction.rollback();
			}
			throw new ServletException(t);
		} 
		
	}

}
