/**
 * Universitat Oberta de Catalunya
 * Ingeniera de Informtica
 * Proyecto fin de carrera
 * 
 * @author      Miguel Arias Fernndez 
 * @version     1.0    
 * 
 */
package es.uoc.maf.core.action.utils;

import java.util.Locale;

import javax.servlet.ServletContext;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import es.uoc.maf.core.Constants;

/**
 * The Class ActionContext.
 * 
 * @author Miguel Arias Fernndez
 * @version 1.0
 */
public class ActionContext {
	
	/** The Constant LOG. */
	private static final Logger LOG = LoggerFactory.getLogger(ActionContext.class);
	
	/** The Constant localeThreadLocal. */
	private static final ThreadLocal<Locale> localeThreadLocal = new InheritableThreadLocal<Locale>();
	
	/** The request. */
	private HttpServletRequest request;
	
	/** The response. */
	private HttpServletResponse response;
	
	/** The servlet context. */
	private ServletContext servletContext;

	
	/**
	 * Instantiates a new action context.
	 * 
	 * @param request
	 *            the request
	 * @param response
	 *            the response
	 * @param servletContext
	 *            the servlet context
	 */
	public ActionContext(HttpServletRequest request, HttpServletResponse response, ServletContext servletContext) {
		LOG.debug("Creando action context...");
		this.request = request;
		this.response = response;
		this.servletContext = servletContext;
		// Recuperamos el locale
		Locale locale = (Locale)getSession().getAttribute(Constants.LOCALE_KEY);
		if (locale == null) {
			setLocale(request.getLocale());
		}
		// Lo guardamos en la request para poder usar posteriormente en lugares donde no
		// sea accesible este contexto, por ejemplo, en los TAGS
		this.request.setAttribute(Constants.ACTION_CONTEXT_KEY, this);
		LOG.debug("Action context creado.");
	}

	/**
	 * Gets the request.
	 * 
	 * @return the request
	 */
	public HttpServletRequest getRequest() {
		return request;
	}

	/**
	 * Gets the session.
	 * 
	 * @return the session
	 */
	public HttpSession getSession() {
		return request.getSession(true);
	}

	/**
	 * Gets the response.
	 * 
	 * @return the response
	 */
	public HttpServletResponse getResponse() {
		return response;
	}

	/**
	 * Gets the servlet context.
	 * 
	 * @return the servlet context
	 */
	public ServletContext getServletContext() {
		return servletContext;
	}

	/**
	 * Gets the locale.
	 * 
	 * @return the locale
	 */
	public static Locale getLocale() {
		Locale locale = localeThreadLocal.get();
		return locale == null ? Locale.getDefault() : locale;
	}
	
	/**
	 * Sets the locale.
	 * 
	 * @param locale
	 *            the new locale
	 */
	public void setLocale(Locale locale) {
		localeThreadLocal.set(locale);
		getSession().setAttribute(Constants.LOCALE_KEY, locale);
		response.setLocale(locale);
	}
}
