/**
 * Universitat Oberta de Catalunya
 * Ingeniera de Informtica
 * Proyecto fin de carrera
 * 
 * @author      Miguel Arias Fernndez 
 * @version     1.0    
 * 
 */
package es.uoc.maf.core.form.utils;

import java.lang.reflect.InvocationTargetException;
import java.util.Iterator;
import java.util.Locale;
import java.util.Map;

import org.apache.commons.beanutils.ConversionException;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import es.uoc.maf.core.exceptions.CoreException;
import es.uoc.maf.core.form.FormBean;
import es.uoc.maf.core.form.FormError;
import es.uoc.maf.core.locale.I18N;

/**
 * The Class BeanUtils.
 * 
 * @author Miguel Arias Fernndez
 * @version 1.0
 */
public class BeanUtils {
	
	/** The log. */
	private Logger log = LoggerFactory.getLogger(BeanUtils.class);

	/** The Constant _instance. */
	private static final BeanUtils _instance = new BeanUtils();

	/**
	 * Instantiates a new bean utils.
	 */
	private BeanUtils() {
		// Constructor privado
	}

	/**
	 * Gets the single instance of BeanUtils.
	 * 
	 * @return single instance of BeanUtils
	 */
	public static BeanUtils getInstance() {
		return _instance;
	}

	/**
	 * Populate.
	 * 
	 * @param bean
	 *            the bean
	 * @param propertiesMap
	 *            the properties map
	 * @param locale
	 *            the locale
	 * @throws IllegalAccessException
	 *             the illegal access exception
	 * @throws InvocationTargetException
	 *             the invocation target exception
	 */
	@SuppressWarnings("rawtypes")
	public void populate(Object bean, Map<String, String> propertiesMap, Locale locale) throws IllegalAccessException, InvocationTargetException {
		log.debug("populate({},{})", bean, propertiesMap);
		// Si no hay bean o propiedades, salimos...
		if (bean == null || propertiesMap == null || propertiesMap.isEmpty()) {
			return ;
		}

		// Iteramos las propiedades...
		Iterator entries = propertiesMap.entrySet().iterator();
		while (entries.hasNext()) {

			Map.Entry entry = (Map.Entry) entries.next();
			String name = (String) entry.getKey();
			if (StringUtils.isBlank(name)) {
				continue;
			}

			try {
				// Intentamos asignar la propiedad
				org.apache.commons.beanutils.BeanUtils.setProperty(bean, name, entry.getValue());
			} catch (ConversionException ce) {
				log.debug("Error convirtiendo propiedad '{}': {}", name, ce.getMessage());
				if (bean instanceof FormBean) {
					String localizedPropertyName = I18N.getString(bean.getClass(), name+".invalido", locale);
					((FormBean)bean).addError(
							new FormError(name, localizedPropertyName));// Buscamos el nombre de la propiedad en el archivo de recursos del formulario
				}
				else {
					throw new CoreException(ce.getLocalizedMessage(), ce);
				}
			}
		}
	}
	
	/**
	 * Gets the property.
	 * 
	 * @param bean
	 *            the bean
	 * @param property
	 *            the property
	 * @return the property
	 * @throws IllegalAccessException
	 *             the illegal access exception
	 * @throws InvocationTargetException
	 *             the invocation target exception
	 * @throws NoSuchMethodException
	 *             the no such method exception
	 */
	public Object getProperty(Object bean, String property) throws IllegalAccessException, InvocationTargetException, NoSuchMethodException {
		return org.apache.commons.beanutils.BeanUtils.getProperty(bean, property);
	}

}
