/**
 * Universitat Oberta de Catalunya
 * Ingeniera de Informtica
 * Proyecto fin de carrera
 * 
 * @author      Miguel Arias Fernndez 
 * @version     1.0    
 * 
 */
package es.uoc.maf.framework.action;

import java.util.ArrayList;
import java.util.List;

import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import es.uoc.maf.core.action.Action;
import es.uoc.maf.core.action.utils.ActionContext;
import es.uoc.maf.core.enums.ActionResults;
import es.uoc.maf.core.form.FormBean;

/**
 * The Class BaseAction.
 * 
 * @author Miguel Arias Fernndez
 * @version 1.0
 */
public class BaseAction implements Action {
	
	/** The Constant log. */
	private static final Logger log = LoggerFactory.getLogger(BaseAction.class);
	
	/** The form. */
	private FormBean form = null;
	
	/** The action messages. */
	private List<String> actionMessages = new ArrayList<String>();
	
	/** The action errors. */
	private List<String> actionErrors = new ArrayList<String>();
	
	/** The action context. */
	private ActionContext actionContext;
	
	/* (non-Javadoc)
	 * @see es.uoc.maf.core.action.Action#getActionMessages()
	 */
	public List<String> getActionMessages() {
		return actionMessages;
	}

	/* (non-Javadoc)
	 * @see es.uoc.maf.core.action.Action#getActionErrors()
	 */
	public List<String> getActionErrors() {
		return actionErrors;
	}

	/* (non-Javadoc)
	 * @see es.uoc.maf.core.action.Action#getActionContext()
	 */
	public ActionContext getActionContext() {
		return actionContext;
	}
	
	/* (non-Javadoc)
	 * @see es.uoc.maf.core.action.Action#setActionContext(es.uoc.maf.core.action.utils.ActionContext)
	 */
	public void setActionContext(ActionContext actionContext) {
		this.actionContext = actionContext;
	}

	/* (non-Javadoc)
	 * @see es.uoc.maf.core.action.Action#getForm()
	 */
	public FormBean getForm() {
		return form;
	}

	/* (non-Javadoc)
	 * @see es.uoc.maf.core.action.Action#setForm(es.uoc.maf.core.form.FormBean)
	 */
	public void setForm(FormBean form) {
		log.debug("BaseAction.setForm({})",form);
		this.form = form;
	}

	/**
	 * Adds the action message.
	 * 
	 * @param message
	 *            the message
	 */
	public void addActionMessage(String message) {
		if (StringUtils.isNotBlank(message)) {
			actionMessages.add(message);
		}
	}
	
	/**
	 * Adds the action error.
	 * 
	 * @param error
	 *            the error
	 */
	public void addActionError(String error) {
		if (StringUtils.isNotBlank(error)) {
			actionErrors.add(error);
		}
 	}
	
	/* (non-Javadoc)
	 * @see es.uoc.maf.core.action.Action#execute()
	 */
	public String execute() {
		log.debug("BaseAction.execute(): Ejecutando accin por defecto (return OK)");
		return ActionResults.OK.name();
	}

}
