/**
 * Universitat Oberta de Catalunya
 * Ingeniera de Informtica
 * Proyecto fin de carrera
 * 
 * @author      Miguel Arias Fernndez 
 * @version     1.0    
 * 
 */
package es.uoc.maf.framework.config.jaxb.impl;

import java.util.HashMap;
import java.util.Map;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;

import es.uoc.maf.core.Constants;
import es.uoc.maf.core.action.Action;
import es.uoc.maf.core.config.ActionConfig;
import es.uoc.maf.core.config.ErrorHandlerConfig;
import es.uoc.maf.core.config.ResultTypeConfig;

/**
 * The Class JAXBActionConfig.
 * 
 * @author Miguel Arias Fernndez
 * @version 1.0
 */
@XmlAccessorType(XmlAccessType.FIELD)
public class JAXBActionConfig implements ActionConfig {

	/** The name. */
	@XmlAttribute(name="name", required=true)
	private String name;
	
	/** The action class. */
	@XmlJavaTypeAdapter(value=JAXBActionClassAdapter.class)
	@XmlAttribute(name="class", required=true)
	private Class<Action> actionClass;
	
	/** The form name. */
	@XmlAttribute(name="form", required=false)
	private String formName;

	/** The results config. */
	@XmlJavaTypeAdapter(value=JAXBResultTypeConfigAdapter.class)
	@XmlElement(name="results", namespace=Constants.MAF_NAMESPACE)
	private HashMap<String, JAXBResultTypeConfig> resultsConfig;

	/** The errors config. */
	@XmlJavaTypeAdapter(value=JAXBResultTypeConfigAdapter.class)
	@XmlElement(name="errors", namespace=Constants.MAF_NAMESPACE)
	private HashMap<Class<Throwable>, JAXBErrorHandlerConfig> errorsConfig;

	/* (non-Javadoc)
	 * @see es.uoc.maf.core.config.ActionConfig#getName()
	 */
	public String getName() {
		return name;
	}

	/* (non-Javadoc)
	 * @see es.uoc.maf.core.config.ActionConfig#getActionClass()
	 */
	public Class<Action> getActionClass() {
		return actionClass;
	}

	/* (non-Javadoc)
	 * @see es.uoc.maf.core.config.ActionConfig#getFormName()
	 */
	public String getFormName() {
		return formName;
	}

	/* (non-Javadoc)
	 * @see es.uoc.maf.core.config.ActionConfig#getResultTypesConfig()
	 */
	public HashMap<String, ResultTypeConfig> getResultTypesConfig() {
		return resultsConfig == null ? new HashMap<String, ResultTypeConfig>() : new HashMap<String, ResultTypeConfig>(resultsConfig);
	}

	/* (non-Javadoc)
	 * @see es.uoc.maf.core.config.ActionConfig#getErrorsConfig()
	 */
	public Map<Class<Throwable>, ErrorHandlerConfig> getErrorsConfig() {
		return errorsConfig == null ? new HashMap<Class<Throwable>, ErrorHandlerConfig>() : new HashMap<Class<Throwable>, ErrorHandlerConfig>(errorsConfig);
	}

}
