/**
 * Universitat Oberta de Catalunya
 * Ingeniera de Informtica
 * Proyecto fin de carrera
 * 
 * @author      Miguel Arias Fernndez 
 * @version     1.0    
 * 
 */
package es.uoc.maf.framework.config.jaxb.impl;

import javax.xml.bind.annotation.adapters.XmlAdapter;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * The Class JAXBClassAdapter.
 * 
 * @param <T>
 *            the generic type
 * @author Miguel Arias Fernndez
 * @version 1.0
 */
class JAXBClassAdapter<T> extends XmlAdapter<String, Class<T>> {
	
	/** The Constant log. */
	private static final Logger log = LoggerFactory.getLogger(JAXBClassAdapter.class);
	
	/* (non-Javadoc)
	 * @see javax.xml.bind.annotation.adapters.XmlAdapter#marshal(java.lang.Object)
	 */
	@Override
	public String marshal(Class<T> clazz) throws Exception {
		log.debug("marshal {}",clazz);
		return clazz.getName();
	}

	/* (non-Javadoc)
	 * @see javax.xml.bind.annotation.adapters.XmlAdapter#unmarshal(java.lang.Object)
	 */
	@Override
	@SuppressWarnings("unchecked")
	public Class<T> unmarshal(String className) throws Exception {
		log.debug("unmarshal {}",className);
		Class<?> clazz = Class.forName(className);
		log.debug("unmarshal class {}",clazz);
		return (Class<T>) clazz;
	}

}
