/**
 * Universitat Oberta de Catalunya
 * Ingeniera de Informtica
 * Proyecto fin de carrera
 * 
 * @author      Miguel Arias Fernndez 
 * @version     1.0    
 * 
 */
package es.uoc.maf.framework.config.jaxb.impl;

import java.util.HashMap;
import java.util.Map;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;

import es.uoc.maf.core.Constants;
import es.uoc.maf.core.config.ActionConfig;
import es.uoc.maf.core.config.Configuration;
import es.uoc.maf.core.config.ErrorHandlerConfig;
import es.uoc.maf.core.config.FormBeanConfig;
import es.uoc.maf.core.config.ResultTypeConfig;

/**
 * The Class JAXBConfiguration.
 * 
 * @author Miguel Arias Fernndez
 * @version 1.0
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlRootElement(name="configuration", namespace=Constants.MAF_NAMESPACE)
public class JAXBConfiguration implements Configuration {

	/** The global results. */
	@XmlJavaTypeAdapter(value=JAXBResultTypeConfigAdapter.class)
	@XmlElement(name="global-results", namespace=Constants.MAF_NAMESPACE)
	private HashMap<String, JAXBResultTypeConfig> globalResults;

	/** The global errors. */
	@XmlJavaTypeAdapter(value=JAXBErrorHandlerConfigAdapter.class)
	@XmlElement(name="global-errors", namespace=Constants.MAF_NAMESPACE)
	private HashMap<Class<Throwable>, JAXBErrorHandlerConfig> globalErrors;

	/** The form beans. */
	@XmlJavaTypeAdapter(value=JAXBFormBeanAdapter.class)
	@XmlElement(name="form-beans", namespace=Constants.MAF_NAMESPACE)
	private HashMap<String, JAXBFormBeanConfig> formBeans;
	
	/** The action mappings. */
	@XmlJavaTypeAdapter(value=JAXBActionMappingsAdapter.class)
	@XmlElement(name="actions", namespace=Constants.MAF_NAMESPACE)
	private HashMap<String, JAXBActionConfig> actionMappings;
	
	/* (non-Javadoc)
	 * @see es.uoc.maf.core.config.Configuration#getActionMappings()
	 */
	public Map<String, ActionConfig> getActionMappings() {
		return actionMappings == null ? new HashMap<String, ActionConfig>() : new HashMap<String, ActionConfig>(actionMappings);
	}

	/* (non-Javadoc)
	 * @see es.uoc.maf.core.config.Configuration#getGlobalResults()
	 */
	public Map<String, ResultTypeConfig> getGlobalResults() {
		return globalResults == null ? new HashMap<String, ResultTypeConfig>() : new HashMap<String, ResultTypeConfig>(globalResults);
	}

	/* (non-Javadoc)
	 * @see es.uoc.maf.core.config.Configuration#getGlobalErrors()
	 */
	public Map<Class<Throwable>, ErrorHandlerConfig> getGlobalErrors() {
		return globalErrors == null ? new HashMap<Class<Throwable>, ErrorHandlerConfig>() : new HashMap<Class<Throwable>, ErrorHandlerConfig>(globalErrors);
	}

	/* (non-Javadoc)
	 * @see es.uoc.maf.core.config.Configuration#getFormBeans()
	 */
	public Map<String, FormBeanConfig> getFormBeans() {
		return formBeans == null ? new HashMap<String, FormBeanConfig>() : new HashMap<String, FormBeanConfig>(formBeans);
	}
	
}
