/**
 * Universitat Oberta de Catalunya
 * Ingeniera de Informtica
 * Proyecto fin de carrera
 * 
 * @author      Miguel Arias Fernndez 
 * @version     1.0    
 * 
 */
package es.uoc.maf.framework.config.jaxb.impl;

import java.io.InputStream;

import javax.xml.bind.JAXBContext;
import javax.xml.bind.JAXBException;
import javax.xml.bind.Unmarshaller;
import javax.xml.bind.ValidationEvent;
import javax.xml.bind.ValidationEventHandler;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import es.uoc.maf.core.config.Configuration;
import es.uoc.maf.core.config.ConfigurationFactory;
import es.uoc.maf.core.exceptions.ConfigurationException;

/**
 * Factoria para crear JAXBConfiguration.
 * 
 * @author      Miguel Arias Fernndez 
 * @version     1.0    
 */
public class JAXBConfigurationFactory extends ConfigurationFactory {
	
	/** The Constant log. */
	private static final Logger log = LoggerFactory.getLogger(JAXBConfigurationFactory.class);
	
	/* (non-Javadoc)
	 * @see es.uoc.maf.core.config.ConfigurationFactory#loadConfig(java.io.InputStream)
	 */
	@Override
	protected Configuration loadConfig(InputStream is) throws JAXBException {
		log.debug("Cargando configuracin...");
		//JAXBContext context = JAXBContext.newInstance(JAXBConfiguration.class);
		JAXBContext context = JAXBContext.newInstance(
				JAXBConfigurationFactory.class.getPackage().getName(),
				JAXBConfigurationFactory.class.getClassLoader());
		Unmarshaller unmarshaller = context.createUnmarshaller();
		unmarshaller.setEventHandler(new ValidationEventHandler() {
			
			public boolean handleEvent(ValidationEvent ve) {
				log.debug("Error recuperando configuracin: {}",ve.getMessage(),ve.getLinkedException());
				throw new ConfigurationException(ve.getMessage(),ve.getLinkedException());
			}
		});
		return (Configuration) unmarshaller.unmarshal(is);
	}

}
