/**
 * Universitat Oberta de Catalunya
 * Ingeniera de Informtica
 * Proyecto fin de carrera
 * 
 * @author      Miguel Arias Fernndez 
 * @version     1.0    
 * 
 */
package es.uoc.maf.framework.config.jaxb.impl;

import java.util.Map;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;

import es.uoc.maf.core.Constants;
import es.uoc.maf.core.config.ErrorHandlerConfig;
import es.uoc.maf.core.error.ErrorHandler;


/**
 * The Class JAXBErrorHandlerConfig.
 * 
 * @author Miguel Arias Fernndez
 * @version 1.0
 */
@XmlAccessorType(XmlAccessType.FIELD)
class JAXBErrorHandlerConfig implements ErrorHandlerConfig {

	/** The error type class. */
	@XmlJavaTypeAdapter(value=JAXBThrowableClassAdapter.class)
	@XmlAttribute(name="type",required=true)
	private Class<Throwable> errorTypeClass;

	/** The error handler class. */
	@XmlJavaTypeAdapter(value=JAXBErrorHandlerClassAdapter.class)
	@XmlAttribute(name="class",required=true)
	private Class<ErrorHandler> errorHandlerClass;

	/** The parameters. */
	@XmlJavaTypeAdapter(value=JAXBParameterAdapter.class)
	@XmlElement(name="parameters",namespace=Constants.MAF_NAMESPACE)
	private Map<String, String> parameters;
	
	/* (non-Javadoc)
	 * @see es.uoc.maf.core.config.ErrorHandlerConfig#getErrorTypeClass()
	 */
	public Class<Throwable> getErrorTypeClass() {
		return this.errorTypeClass;
	}
	
	/* (non-Javadoc)
	 * @see es.uoc.maf.core.config.ErrorHandlerConfig#getErrorHandlerClass()
	 */
	public Class<ErrorHandler> getErrorHandlerClass() {
		return this.errorHandlerClass;
	}

	/* (non-Javadoc)
	 * @see es.uoc.maf.core.config.ErrorHandlerConfig#getParameters()
	 */
	public Map<String, String> getParameters() {
		return parameters;
	}

	/* (non-Javadoc)
	 * @see java.lang.Object#toString()
	 */
	@Override
	public String toString() {
		return "JAXBErrorHandlerConfig [errorTypeClass=" + errorTypeClass
				+ ", errorHandlerClass=" + errorHandlerClass + ", parameters="
				+ parameters + "]";
	}
	
}
