/**
 * Universitat Oberta de Catalunya
 * Ingeniera de Informtica
 * Proyecto fin de carrera
 * 
 * @author      Miguel Arias Fernndez 
 * @version     1.0    
 * 
 */
package es.uoc.maf.framework.config.jaxb.impl;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.Map;

import javax.xml.bind.annotation.adapters.XmlAdapter;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * The Class JAXBErrorHandlerConfigAdapter.
 * 
 * @author Miguel Arias Fernndez
 * @version 1.0
 */
class JAXBErrorHandlerConfigAdapter  extends XmlAdapter<JAXBErrorHandlerConfigListWrapper, Map<Class<Throwable>, JAXBErrorHandlerConfig>>  {
	
	/** The Constant log. */
	private static final Logger log = LoggerFactory.getLogger(JAXBErrorHandlerConfigAdapter.class);
	
	/* (non-Javadoc)
	 * @see javax.xml.bind.annotation.adapters.XmlAdapter#marshal(java.lang.Object)
	 */
	@Override
	public JAXBErrorHandlerConfigListWrapper marshal(Map<Class<Throwable>, JAXBErrorHandlerConfig> globalErrors) throws Exception {
		JAXBErrorHandlerConfigListWrapper wrapper = new JAXBErrorHandlerConfigListWrapper();
		wrapper.setGlobalErrors(new ArrayList<JAXBErrorHandlerConfig>(globalErrors.values()));
		return wrapper;
	}

	/* (non-Javadoc)
	 * @see javax.xml.bind.annotation.adapters.XmlAdapter#unmarshal(java.lang.Object)
	 */
	@Override
	public Map<Class<Throwable>, JAXBErrorHandlerConfig> unmarshal(JAXBErrorHandlerConfigListWrapper arg0) throws Exception {
		log.debug("unmarshall: {}",arg0.getGlobalErrors());
		Map<Class<Throwable>, JAXBErrorHandlerConfig> result = new HashMap<Class<Throwable>, JAXBErrorHandlerConfig>(arg0 == null || arg0.getGlobalErrors() == null ? 0 : arg0.getGlobalErrors().size());
		if (arg0 != null && arg0.getGlobalErrors() != null) {
			for (JAXBErrorHandlerConfig eh : arg0.getGlobalErrors()) {
				result.put(eh.getErrorTypeClass(), eh);
			}
		}
		return result;
	}

}
