/**
 * Universitat Oberta de Catalunya
 * Ingeniera de Informtica
 * Proyecto fin de carrera
 * 
 * @author      Miguel Arias Fernndez 
 * @version     1.0    
 * 
 */
package es.uoc.maf.framework.config.jaxb.impl;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.Map;
import java.util.Map.Entry;

import javax.xml.bind.annotation.adapters.XmlAdapter;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * The Class JAXBParameterAdapter.
 * 
 * @author Miguel Arias Fernndez
 * @version 1.0
 */
class JAXBParameterAdapter extends XmlAdapter<JAXBParameterListWrapper, Map<String, String>> {
	
	/** The Constant LOG. */
	private static final Logger LOG = LoggerFactory.getLogger(JAXBParameterAdapter.class);
	
	/* (non-Javadoc)
	 * @see javax.xml.bind.annotation.adapters.XmlAdapter#marshal(java.lang.Object)
	 */
	@Override
	public JAXBParameterListWrapper marshal(Map<String, String> parameters) throws Exception {
		JAXBParameterListWrapper result = new JAXBParameterListWrapper();
		result.setParametersList(new ArrayList<JAXBParameter>());
		if (parameters != null) {
			for (Entry<String, String> e : parameters.entrySet()) {
				result.getParametersList().add(new JAXBParameter(e.getKey(),e.getValue()));
			}
		}
		return result;
	}

	/* (non-Javadoc)
	 * @see javax.xml.bind.annotation.adapters.XmlAdapter#unmarshal(java.lang.Object)
	 */
	@Override
	public Map<String, String> unmarshal(JAXBParameterListWrapper parametersWrapper) throws Exception {
		LOG.debug("unmarshal: {}",parametersWrapper.getParametersList());
		Map<String, String> parameters = new HashMap<String, String>();
		if (parametersWrapper != null) {
			for (JAXBParameter p : parametersWrapper.getParametersList()) {
				parameters.put(p.getName(), p.getValue());
			}
		}
		return parameters;
	}

}
