/**
 * Universitat Oberta de Catalunya
 * Ingeniera de Informtica
 * Proyecto fin de carrera
 * 
 * @author      Miguel Arias Fernndez 
 * @version     1.0    
 * 
 */
package es.uoc.maf.framework.config.jaxb.impl;

import java.util.Map;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;

import es.uoc.maf.core.Constants;
import es.uoc.maf.core.config.ResultTypeConfig;
import es.uoc.maf.core.result.ResultType;

/**
 * The Class JAXBResultTypeConfig.
 * 
 * @author Miguel Arias Fernndez
 * @version 1.0
 */
@XmlAccessorType(XmlAccessType.FIELD)
class JAXBResultTypeConfig implements ResultTypeConfig {

	/** The name. */
	@XmlAttribute(name="name",required=true)
	private String name;
	
	/** The result type class. */
	@XmlJavaTypeAdapter(value=JAXBResultTypeClassAdapter.class)
	@XmlAttribute(name="class",required=true)
	private Class<ResultType> resultTypeClass;

	/** The parameters. */
	@XmlJavaTypeAdapter(value=JAXBParameterAdapter.class)
	@XmlElement(name="parameters",namespace=Constants.MAF_NAMESPACE)
	private Map<String, String> parameters;
	
	/* (non-Javadoc)
	 * @see es.uoc.maf.core.config.ResultTypeConfig#getName()
	 */
	public String getName() {
		return this.name;
	}

	/* (non-Javadoc)
	 * @see es.uoc.maf.core.config.ResultTypeConfig#getResultTypeClass()
	 */
	public Class<ResultType> getResultTypeClass() {
		return this.resultTypeClass;
	}

	/* (non-Javadoc)
	 * @see es.uoc.maf.core.config.ResultTypeConfig#getParameters()
	 */
	public Map<String, String> getParameters() {
		return parameters;
	}

	/* (non-Javadoc)
	 * @see java.lang.Object#toString()
	 */
	@Override
	public String toString() {
		return "JAXBResultTypeConfig [name=" + name + ", resultTypeClass="
				+ resultTypeClass + ", parameters=" + parameters + "]";
	}
	
}
