/**
 * Universitat Oberta de Catalunya
 * Ingeniera de Informtica
 * Proyecto fin de carrera
 * 
 * @author      Miguel Arias Fernndez 
 * @version     1.0    
 * 
 */
package es.uoc.maf.framework.config.jaxb.impl;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.Map;

import javax.xml.bind.annotation.adapters.XmlAdapter;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * The Class JAXBResultTypeConfigAdapter.
 * 
 * @author Miguel Arias Fernndez
 * @version 1.0
 */
class JAXBResultTypeConfigAdapter  extends XmlAdapter<JAXBResultTypeConfigListWrapper, Map<String, JAXBResultTypeConfig>>  {
	
	/** The Constant log. */
	private static final Logger log = LoggerFactory.getLogger(JAXBResultTypeConfigAdapter.class);
	
	/* (non-Javadoc)
	 * @see javax.xml.bind.annotation.adapters.XmlAdapter#marshal(java.lang.Object)
	 */
	@Override
	public JAXBResultTypeConfigListWrapper marshal(Map<String, JAXBResultTypeConfig> globalResults) throws Exception {
		JAXBResultTypeConfigListWrapper wrapper = new JAXBResultTypeConfigListWrapper();
		wrapper.setGlobalResults(new ArrayList<JAXBResultTypeConfig>(globalResults.values()));
		return wrapper;
	}

	/* (non-Javadoc)
	 * @see javax.xml.bind.annotation.adapters.XmlAdapter#unmarshal(java.lang.Object)
	 */
	@Override
	public Map<String, JAXBResultTypeConfig> unmarshal(JAXBResultTypeConfigListWrapper arg0) throws Exception {
		log.debug("unmarshall: {}",arg0.getGlobalResults());
		Map<String, JAXBResultTypeConfig> result = new HashMap<String, JAXBResultTypeConfig>(arg0 == null || arg0.getGlobalResults() == null ? 0 : arg0.getGlobalResults().size());
		if (arg0 != null && arg0.getGlobalResults() != null) {
			for (JAXBResultTypeConfig rt : arg0.getGlobalResults()) {
				result.put(rt.getName(), rt);
			}
		}
		return result;
	}

}
